{ pkgs ? import <nixpkgs> {} }:

let
  rpi-gpio = pkgs.python3Packages.buildPythonPackage {
    pname = "RPi.GPIO";
    version = "0.6.3";

    src = builtins.fetchTarball {
      url = "https://github.com/jfath/RPi.GPIO-Odroid/archive/1bf20794e6727631f2b4b053296455eba900507e.tar.gz";
      sha256 = "0xf64d88xvly7w8g2fbvdl4azp79ikxf49i1wlkrb3abfakmqc3p";
    };

    patches = [
      ./odroid-c2.patch
    ];

    doChceck = false;

    propagatedBuildInputs = with pkgs.python3Packages; [];
  };
  smbus = pkgs.python3Packages.buildPythonPackage rec {
    pname = "smbus";
    version = "1.1.post2";

    src = pkgs.python3.pkgs.fetchPypi {
      inherit pname version;
      sha256 = "+W00XgqhAFOopJF2NPHcN7ofZW+lys52KbcXd+kIVcY=";
    };

    doChceck = false;

    propagatedBuildInputs = with pkgs.python3Packages; [];
  };
  iot-message = pkgs.python3Packages.buildPythonPackage rec {
    pname = "iot_message";
    version = "1.2.1";

    src = pkgs.python3.pkgs.fetchPypi {
      inherit pname version;
      sha256 = "BYvREaBM9Ut0bS7SuKUiavo/wemDzNkwa5beiEzifZ4=";
    };

    doChceck = false;

    propagatedBuildInputs = with pkgs.python3Packages; [ pycrypto ];

    meta = {
      homepage = "https://github.com/bkosciow/python_iot-1";
      description = "My custom protocol for communication between devices at home. It uses UPD and broadcast. Messages are json strings.";
      license = pkgs.lib.licenses.mit;
    };
  };
  message-listener = pkgs.python3Packages.buildPythonPackage rec {
    pname = "message_listener";
    version = "1.1.0";

    src = pkgs.python3.pkgs.fetchPypi {
      inherit pname version;
      sha256 = "yk+9rptdktaRXWF4kvs6na3bOB9MAoYNlrjva4FcR5A=";
    };

    doChceck = false;

    propagatedBuildInputs = with pkgs.python3Packages; [ iot-message ];

    meta = {
      homepage = "https://github.com/bkosciow/message_listener";
      description = "App used at Raspberry Pi as receiver of incoming messages and pass them to registered handlers (relay, screen, sensors)";
      license = pkgs.lib.licenses.mit;
    };
  };
  charlcd = pkgs.python3Packages.buildPythonPackage rec {
    pname = "charlcd";
    version = "0.6";

    src = pkgs.python3.pkgs.fetchPypi {
      inherit pname version;
      sha256 = "BOQUfKYl0ouCW+oCYNbZj/1oxcEKWF40S22GK7Vafeg=";
    };

    patches = [
      ./charlcd.patch
    ];

    doChceck = false;

    propagatedBuildInputs = with pkgs.python3Packages; [ future message-listener smbus rpi-gpio ];

    meta = {
      homepage = "https://bitbucket.org/kosci/charlcd/";
      description = "handler for char lcds Hitatchi HD44780";
      license = pkgs.lib.licenses.mit;
    };
  };
in
  pkgs.python38.withPackages (ps: [ charlcd ])